**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Nom              beefCattleFarm.gms
Sequence         2 - The farm model
Type             LP
Langage GAMS     3 dimensional tables. Indexed equations
Description
 Livestock Model
$Offtext
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*


*----------                          INDICES                        ----------*
sets
C crops  /barley,grass,hay/
A cattle present /cow,FVeal,MVeal,bull1,bull2,heifer1,heifer2,heifer3/
;

*----------                           DATA                       ----------*
scalar
Land_A  land availability (crops)       /100/
Labour_A     labour availability in hours    /2000/
PROL     prolificity                             /0.9/
SEXRATIO sex ratio                                /0.5/
RENEW   renewal rate                             /0.18/
CULLING   culling rate                             /0.18/
;

parameter

LabourNeeds(C)         labour needs per crops
/barley   20
 grass   8
 hay   10/

PRICE(C) crop prices (euros per kg)
/barley  0.10/

YLD(C) yield per crop (kg par hectare)
/barley  6000
 grass 2000
 hay  3000/

COST(C) costs (euros per ha)
/barley  380
 grass  50
 hay  100/

LabourNeedsA(a)  labour needs (hours per ha and per year)
/cow   10
 FVeal    4
 MVeal    4
 bull1    6
 bull2    3
 heifer1 4
 heifer2 6
 heifer3 8/

PRICEA(A) cattle price (euros)
/cow    1000
 MVeal     650
 FVeal     695
 bull2     929
 heifer3 1200/
;

table FeedNeeds(A,C) feeding needs (KG per animal)
          barley      hay      grass
 cow       661      1543       1187
 MVeal     119       474        365
 FVeal     119       474        365
 bull1    1044      1392
 bull2     204       818
 heifer1   143       570        438
 heifer2   204       818        629
 heifer3   234       934        718
;

*----------                         MODEL                          ----------*

variable Z income ;

positive variables
N(A)     animal number
X(C)     land area per crop
cS(C)     crop sold
AS(A)    animal sold
;

equations

OBJ              ojective function
LAND             land equation
LABOUR           labour equation
FEED(C)          feed equation
DEMO1            male prolificity
DEMO2            female prolificity
DEMO3            same number of heifers year 1 and 2
DEMO4            same number of heifers year 2 and 3
DEMO5            same number of bull calves year 1 and 2
SOLD1           culling cows sold
SOLD2           bull calves sold
SOLD3           heifers sold
SOLD4           female veal calves sold
SOLD5           male veal calves sold

;

OBJ.. sum (A, AS(A)*PRICEA(A)) + sum(C, CS(C)*PRICE(C)) - sum(C,X(C)*COST(C)) =e= Z ;

LABOUR.. sum (A, LabourNeedsA(A)*N(A))+ sum(C, LabourNeeds(C)*X(C) ) =l= Labour_A ;

LAND.. sum(C, X(C)) =l= Land_A ;

FEED(C).. sum(A, FeedNeeds(A,C)*N(A)) =l= YLD(C)*X(C)-CS(c) ;

DEMO1.. N('MVeal') + N('bull1') =e= prol * sexratio * N('cow');

DEMO2.. N('FVeal') + N('heifer1') =e= prol * sexratio * N('cow');

DEMO3.. N('heifer1') =e= N('heifer2');

DEMO4.. N('heifer3') =e= N('heifer2') ;

DEMO5.. N('bull1') =e= N('bull2')   ;

SOLD1.. AS('cow') =e= RENEW * N('cow')   ;

SOLD2.. AS('bull2') =e= N('bull2') ;

SOLD3.. AS('heifer3') =e= N('heifer3') - N('cow')*RENEW ;

SOLD4.. AS('FVeal') =e= N('FVeal')  ;

SOLD5.. AS('MVeal')  =e= N('MVeal') ;


 model livestock /all/;

*----------                        SOLUTION                         ----------*
solve livestock using LP maximizing Z ;


Display N.L, Z.l, X.l, CS.l; 